## Prompt registry (BETA)

Prompt registry is a storage API for versioned prompts. It allows you to store and retrieve prompts from local storage.
Currently, it supports storing templates in a single JSON file or in a file system directory, but it can be extended to
support other storage backends.

### Usage

Coming soon.